// Copyright (C) 2018-2023 Intel Corporation
// SPDX-License-Identifier: Apache-2.0
//

#pragma once

#include <map>
#include <string>

#ifdef OPENVINO_STATIC_LIBRARY

#include "cpp_interfaces/interface/ie_iplugin_internal.hpp"



struct Value {
    InferenceEngine::CreatePluginEngineFunc * m_create_plugin_func;
    InferenceEngine::CreateExtensionFunc * m_create_extension_func;
    std::map<std::string, std::string> m_default_config;
};

#else

struct Value {
    std::string m_plugin_path;
    std::map<std::string, std::string> m_default_config;
};

#endif

using Key = std::string;
using PluginsStaticRegistry = std::map<Key, Value>;


inline const std::map<Key, Value> getCompiledPluginsRegistry() {
    static const std::map<Key, Value> plugins_hpp = {
        { "MULTI", Value { "libopenvino_auto_plugin.so", {} } },
        { "AUTO", Value { "libopenvino_auto_plugin.so", {} } },
        { "BATCH", Value { "libopenvino_auto_batch_plugin.so", {} } },
    };

    return plugins_hpp;
}
